GetDirectoryAndName: GetDirectoryAndName

Description Usage

View source: R/GetDirectoryAndName.R

Description

Function to split the path into the directory name (without the last folder) and name which is created from the last folder.

Usage

1

BioPharmSoftGrp/PREP documentation built on April 5, 2021, 6:20 p.m.